Change Log
**********

..
   All enhancements and patches to help_tokens will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (http://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

[1.0.3] - 2017-07-17
====================

* Updated tests to support Django 1.11
* Updated dependency versions


[1.0.2] - 2017-05-16
====================

* Fixed the README.


[1.0.1] - 2017-05-15
====================

* First version on PyPI.


[1.0.0] - 2017-05-03
====================

* First release.
